--
-- WalletTracker - Lotro Plugin to help track how much wallet stuff is earnt over a period of time
--                 I thought of this when I started useing the Wallet plugin by Garan (which is awesome!).
--
-- Copyright (C) 2012   Random Augury
--
--  This program is free software: you can redistribute it and/or modify
--  it under the terms of the GNU General Public License as published by
--  the Free Software Foundation, either version 3 of the License, or
--  (at your option) any later version.
--
--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.
--
--  You should have received a copy of the GNU General Public License
--  along with this program.  If not, see <http://www.gnu.org/licenses/>.
--	
--	You may contact me at: randomaugury@gmail.com

import "Turbine.Gameplay";

WalletTracker = Turbine.ShellCommand();

walletState = nil;
localPlayer = Turbine.Gameplay.LocalPlayer:GetInstance();
wallet = localPlayer:GetWallet();
anyChanges = false; -- we track this while processing so we can output a message if nothing changed

Turbine.Shell.AddCommand("wallettracker;wt", WalletTracker);


function WalletTracker:GetHelp()
	Turbine.Shell.WriteLine("<rgb=#600000>WalletTracker</rgb> ".. Plugins.WalletTracker:GetVersion());
	Turbine.Shell.WriteLine("/wallettracker or /wt");
	Turbine.Shell.WriteLine("        mark");
	Turbine.Shell.WriteLine("        diff");
end

function WalletTracker:Execute(cmd, args)
	if (args == "mark") then
		MarkWalletState();
	elseif (args == "diff") then
		OutputWalletDifference();
	else
		WalletTracker:GetHelp();
	end
end

function MarkWalletState()
	walletState = {}
	
	walletState["Money"] = localPlayer:GetAttributes():GetMoney();
	walletState["Destiny Point"] = localPlayer:GetAttributes():GetDestinyPoints();
	
	for i = 1, wallet:GetSize() do
		wItem = wallet:GetItem(i);
		walletState[wItem:GetName()] = wItem:GetQuantity();
	end;
	Turbine.Shell.WriteLine("WalletTracker: mark placed");
end;

function OutputWalletDifference()
	if walletState == nil
	then
		Turbine.Shell.WriteLine("WalletTracker: no snapshot taken. use /wt mark first");
	end;
	
	local matchedNames = {};
	anyChanges = false;

	-- compare to the marked version
	for i = 1, wallet:GetSize() do
		wItem = wallet:GetItem(i);
		
--		if (i ~= 3) -- hard coded case to test if all items being removed is tracked properly
--		then
		matchedNames[wallet:GetItem(i):GetName()] = true;
--		end;
		
		if (walletState[wItem:GetName()])
		then
--			if (i ~= 3) -- hard coded case to test if all items being removed is tracked properly
--			then
			CompareAndOutputDifference(wItem:GetName(), wItem:GetQuantity() - walletState[wItem:GetName()]);
--			end;
		else
			CompareAndOutputDifference(wItem:GetName(), wItem:GetQuantity());
		end;
	end;
	
	-- handle special cases for Gold and Destiny points
	CompareAndOutputDifference("Money", (localPlayer:GetAttributes():GetMoney() - walletState["Money"]));
	matchedNames["Money"] = true;
	CompareAndOutputDifference("Destiny Point", localPlayer:GetAttributes():GetDestinyPoints() - walletState["Destiny Point"]);
	matchedNames["Destiny Point"] = true;
	
	-- check to see there are any items that we have COMPLETELY used up
	for k,v in pairs(walletState)
	do
		if (not matchedNames[k])
		then
			CompareAndOutputDifference(k, 0 - v);
		end;
	end;
	
	if (not anyChanges)
	then
		Turbine.Shell.WriteLine("WalletTracker: no changes since mark was placed");
	end;
	
end;

function CompareAndOutputDifference(name, difference)
	local rgbText = "";
	
	if (difference == 0)
	then
		return;
	end;
	
	anyChanges = true;
	
	if difference > 0
	then
		rgbText = "<rgb=#006000>";
	else
		rgbText = "<rgb=#600000>";
	end;
	
	if (name == "Money")
	then
		local gold = math.floor(difference / 100000);
		local silver = math.floor(difference / 100) - gold*1000;
		local copper = difference - gold*1000 - silver*100;
		Turbine.Shell.WriteLine(rgbText .. gold .. "g, " .. silver .. "s, " .. copper .. "c</rgb>");
	else
		Turbine.Shell.WriteLine(rgbText .. name .. " : " .. difference .. "</rgb>");
	end;
end;

Turbine.Shell.WriteLine("<rgb=#600000>WalletTracker</rgb> <rgb=#006060> "
		.. Plugins.WalletTracker:GetVersion()
		.. " by RandomAugury</rgb>");

